<?php

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Application extends \YPS\Framework\Core\v346_950_484\Application {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Base extends \YPS\Framework\Core\v346_950_484\Base {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Config extends \YPS\Framework\Core\v346_950_484\Config {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Context extends \YPS\Framework\Core\v346_950_484\Context {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Controller extends \YPS\Framework\Core\v346_950_484\Controller {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Helper extends \YPS\Framework\Core\v346_950_484\Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Module extends \YPS\Framework\Core\v346_950_484\Module {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class View_Helper extends \YPS\Framework\Core\v346_950_484\View_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class View extends \YPS\Framework\Core\v346_950_484\View {}
}

namespace YPS\WC_Invoice_Plane\Framework\Database {
		class Database_Helper extends \YPS\Framework\Database\v346_950_484\Database_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Database {
		class Entity extends \YPS\Framework\Database\v346_950_484\Entity {}
}

namespace YPS\WC_Invoice_Plane\Framework\Database {
		class Model extends \YPS\Framework\Database\v346_950_484\Model {}
}

namespace YPS\WC_Invoice_Plane\Framework\Database {
		class Search_Query extends \YPS\Framework\Database\v346_950_484\Search_Query {}
}

namespace YPS\WC_Invoice_Plane\Framework\Database {
		class Session_Model extends \YPS\Framework\Database\v346_950_484\Session_Model {}
}

namespace YPS\WC_Invoice_Plane\Framework\File_System {
		class File_System_Helper extends \YPS\Framework\File_System\v346_950_484\File_System_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Button_Form_Field extends \YPS\Framework\Form\v346_950_484\Button_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Button_Group_Form_Field extends \YPS\Framework\Form\v346_950_484\Button_Group_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Checkbox_Form_Field extends \YPS\Framework\Form\v346_950_484\Checkbox_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Checkbox_List_Form_Field extends \YPS\Framework\Form\v346_950_484\Checkbox_List_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Color_Form_Field extends \YPS\Framework\Form\v346_950_484\Color_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Date_Form_Field extends \YPS\Framework\Form\v346_950_484\Date_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class DateTime_Form_Field extends \YPS\Framework\Form\v346_950_484\DateTime_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class File_Form_Field extends \YPS\Framework\Form\v346_950_484\File_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Form_Controller extends \YPS\Framework\Form\v346_950_484\Form_Controller {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Form_Field extends \YPS\Framework\Form\v346_950_484\Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Form_Group extends \YPS\Framework\Form\v346_950_484\Form_Group {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Form_View extends \YPS\Framework\Form\v346_950_484\Form_View {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Form extends \YPS\Framework\Form\v346_950_484\Form {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Label_Form_Field extends \YPS\Framework\Form\v346_950_484\Label_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class List_Form_Field extends \YPS\Framework\Form\v346_950_484\List_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Modal_Form_Field extends \YPS\Framework\Form\v346_950_484\Modal_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Numeric_Form_Field extends \YPS\Framework\Form\v346_950_484\Numeric_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Password_Form_Field extends \YPS\Framework\Form\v346_950_484\Password_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Select_Form_Field extends \YPS\Framework\Form\v346_950_484\Select_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Spinner_Form_Field extends \YPS\Framework\Form\v346_950_484\Spinner_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Text_Form_Field extends \YPS\Framework\Form\v346_950_484\Text_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Time_Form_Field extends \YPS\Framework\Form\v346_950_484\Time_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class Tree_Select_Form_Field extends \YPS\Framework\Form\v346_950_484\Tree_Select_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class WP_Editor_Form_Field extends \YPS\Framework\Form\v346_950_484\WP_Editor_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Form {
		class WP_Media_Form_Field extends \YPS\Framework\Form\v346_950_484\WP_Media_Form_Field {}
}

namespace YPS\WC_Invoice_Plane\Framework\Invoice_Plane {
		class Webservice extends \YPS\Framework\Invoice_Plane\v346_950_484\Webservice {}
}

namespace YPS\WC_Invoice_Plane\Framework\Net {
		class Curl extends \YPS\Framework\Net\v346_950_484\Curl {}
}

namespace YPS\WC_Invoice_Plane\Framework\Net {
		class Url_Helper extends \YPS\Framework\Net\v346_950_484\Url_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Plugin {
		class Plugin_Controller extends \YPS\Framework\Plugin\v346_950_484\Plugin_Controller {}
}

namespace YPS\WC_Invoice_Plane\Framework\Plugin {
		class Plugin extends \YPS\Framework\Plugin\v346_950_484\Plugin {}
}

namespace YPS\WC_Invoice_Plane\Framework\Core {
		class Plugin_Helper extends \YPS\Framework\Core\v346_950_484\Plugin_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Config extends \YPS\Framework\Record\v346_950_484\Record_Config {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Controller extends \YPS\Framework\Record\v346_950_484\Record_Controller {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Entity extends \YPS\Framework\Record\v346_950_484\Record_Entity {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Form extends \YPS\Framework\Record\v346_950_484\Record_Form {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Model extends \YPS\Framework\Record\v346_950_484\Record_Model {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Module extends \YPS\Framework\Record\v346_950_484\Record_Module {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Session_Model extends \YPS\Framework\Record\v346_950_484\Record_Session_Model {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_Table extends \YPS\Framework\Record\v346_950_484\Record_Table {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record_View extends \YPS\Framework\Record\v346_950_484\Record_View {}
}

namespace YPS\WC_Invoice_Plane\Framework\Record {
		class Record extends \YPS\Framework\Record\v346_950_484\Record {}
}

namespace YPS\WC_Invoice_Plane\Framework\Settings {
		class Settings_Config extends \YPS\Framework\Settings\v346_950_484\Settings_Config {}
}

namespace YPS\WC_Invoice_Plane\Framework\Settings {
		class Settings_Controller extends \YPS\Framework\Settings\v346_950_484\Settings_Controller {}
}

namespace YPS\WC_Invoice_Plane\Framework\Settings {
		class Settings_Entity extends \YPS\Framework\Settings\v346_950_484\Settings_Entity {}
}

namespace YPS\WC_Invoice_Plane\Framework\Settings {
		class Settings_Helper extends \YPS\Framework\Settings\v346_950_484\Settings_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Settings {
		class Settings_Model extends \YPS\Framework\Settings\v346_950_484\Settings_Model {}
}

namespace YPS\WC_Invoice_Plane\Framework\Settings {
		class Settings_Form_View extends \YPS\Framework\Settings\v346_950_484\Settings_Form_View {}
}

namespace YPS\WC_Invoice_Plane\Framework\String {
		class Naming_Helper extends \YPS\Framework\String\v346_950_484\Naming_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\String {
		class String_Helper extends \YPS\Framework\String\v346_950_484\String_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Ajax_Query_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Ajax_Query_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Category_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Category_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Payment_Gateways extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Payment_Gateways {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Product_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Product_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Shipping_Method_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Shipping_Method_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Tax_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Tax_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Woocommerce {
		class Woocommerce_Variable_Product_Helper extends \YPS\Framework\Woocommerce\v346_950_484\Woocommerce_Variable_Product_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Wordpress {
		class Wordpress_Helper extends \YPS\Framework\Wordpress\v346_950_484\Wordpress_Helper {}
}

namespace YPS\WC_Invoice_Plane\Framework\Wordpress {
		class Wordpress_Multisite_Helper extends \YPS\Framework\Wordpress\v346_950_484\Wordpress_Multisite_Helper {}
}

